/**
  ******************************************************************************
  * @file    config.h
  * @author  ingo_s
  * @version V1.0.0
  * @date    2015.01.20
  * @brief   configuration of STRootLoader (STM32F05x)
  ******************************************************************************
  *
  ******************************************************************************
*/
#ifndef _CONFIG_H_
#define _CONFIG_H_


/* Exported constants --------------------------------------------------------*/
/* start address of application */
//#define APPLICATION_ADDRESS     (uint32_t)0x08002000 // Optimize None -Oo
#define APPLICATION_ADDRESS     (uint32_t)0x08001000 // Optimize -O1 / -Os


// define used Port, Pin and PinSource of used USART
// STM32F050 ----------------------
// a) USART1 TX: PA9;  USART1 RX: PA10  ** tested
// b) USART1 TX: PA2;  USART1 RX: PA3
// STM32F051 ----------------------
// a) USART1 TX: PA9;  USART1 RX: PA10	** tested
// b) USART1 TX: PB6;  USART1 RX: PB7
// c) USART2 TX: PA2;  USART2 RX: PA3   ** tested
// d) USART2 TX: PA14; USART2 RX: PA15 (SWCLK on PA14!)

/* define used USART and Baudrate here */
#define BAUDRATE 115200
#define USART_ONE_WIRE

#define USART1_BL		// USART1 used
//#define USART2_BL		// USART2 used

#define GPIO_BL  GPIOA

#define GPIO_Pin_TX      GPIO_Pin_9
#define GPIO_PinSourceTX GPIO_PinSource9

#ifndef USART_ONE_WIRE
#define GPIO_Pin_RX      GPIO_Pin_10
#define GPIO_PinSourceRX GPIO_PinSource10
#endif

#if defined (USART1_BL)
#define USART_BL	USART1
#elif defined(USART2_BL)
#define USART_BL	USART2
#endif

/* Optional - your own bootloader message here, max. 250 chars */
#define BOOTINFO_STRING "STM32F05x"

/* sign of bootloader */
#define BOOTSIGN "BOOTLOADER"

/* Optional - EEPROM Read function */
#define EEPROM_READ_WRITE
#define EEPROM_SIZE 0x0800

/* connection-try timeout [ms] */
#define CONNECT_TIMEOUT_MS 110

/* ******************************************************************************
    -------------------- Application "HOW TO" INFO ------------------------------
	*** Compiler Settings:
	--- You should define the new Memory area Start and FlashSize value
	--- APPLICATION_ADDRESS and Application Flash Size (reduced)
	--- You should define the IRAM for your projects (loader, app)
	--- to start at 0x200000C0, of length 0x1F40 (for 8KB part)

	*** Application Main() Start Actions:
	--- Copy the vector table from the Flash (mapped at the base of the application
	--- load address (APPLICATION_ADDRESS) to the base address of the SRAM at 0x20000000.
	
	*** HEX-FILE edit
	--- delete 1. line with record type 02 (address offset of 0x08000000)

#include "stm32f0xx_syscfg.h"
int main(void)
{
 	uint32_t *VectorTable = (uint32_t *)0x20000000;

	uint32_t i = 0;
	for(i = 0; i < 48; i++)
	  VectorTable[i] = *(__IO uint32_t*)(APPLICATION_ADDRESS + (i<<2));

	//  Enable the SYSCFG peripheral clock
	RCC_APB2PeriphResetCmd(RCC_APB2Periph_SYSCFG, ENABLE);

	//   Remap SRAM at 0x00000000
	SYSCFG_MemoryRemapConfig(SYSCFG_MemoryRemap_SRAM);
    ....
}

***************************************************************************** */

/* ------------------------------------ EOF --------------------------------- */
#endif
